@@ -43,7 +43,7 @@ from unstructured.documents.elements import (
     Title,
 )
 from unstructured.file_utils.filetype import detect_filetype
-from unstructured.file_utils.model import FileType
+from unstructured.file_utils.model import FileType, create_file_type, register_partitioner
 from unstructured.partition.auto import _PartitionerLoader, partition
 from unstructured.partition.common import UnsupportedFileFormatError
 from unstructured.partition.utils.constants import PartitionStrategy
@@ -210,7 +210,7 @@ def test_auto_partition_epub_from_filename():
     elements = partition(example_doc_path("winter-sports.epub"), strategy=PartitionStrategy.HI_RES)
 
     assert len(elements) > 0
-    assert elements[0].text.startswith("The Project Gutenberg eBook of Winter Sports")
+    assert elements[2].text.startswith("The Project Gutenberg eBook of Winter Sports")
 
 
 def test_auto_partition_epub_from_file():
@@ -218,7 +218,7 @@ def test_auto_partition_epub_from_file():
         elements = partition(file=f, strategy=PartitionStrategy.HI_RES)
 
     assert len(elements) > 0
-    assert elements[0].text.startswith("The Project Gutenberg eBook of Winter Sports")
+    assert elements[2].text.startswith("The Project Gutenberg eBook of Winter Sports")
 
 
 # ================================================================================================
@@ -409,17 +409,17 @@ def test_auto_partition_json_from_file_preserves_original_elements():
     assert elements_to_dicts(partitioned_elements) == elements_to_dicts(original_elements)
 
 
-def test_auto_partition_json_raises_with_unprocessable_json(tmp_path: pathlib.Path):
-    # NOTE(robinson) - This is unprocessable because it is not a list of dicts, per the
-    # Unstructured JSON serialization format
-    text = '{"hi": "there"}'
+def test_auto_partition_processes_simple_ndjson(tmp_path: pathlib.Path):
+    text = '{"text": "hello", "type": "NarrativeText"}'
 
     file_path = str(tmp_path / "unprocessable.json")
     with open(file_path, "w") as f:
         f.write(text)
 
-    with pytest.raises(ValueError, match="Detected a JSON file that does not conform to the Unst"):
-        partition(filename=file_path)
+    result = partition(filename=file_path)
+    assert len(result) == 1
+    assert isinstance(result[0], NarrativeText)
+    assert "hello" in result[0].text
 
 
 # ================================================================================================
@@ -430,7 +430,7 @@ def test_auto_partition_json_raises_with_unprocessable_json(tmp_path: pathlib.Pa
 def test_partition_md_from_url_works_with_embedded_html():
     url = "https://raw.githubusercontent.com/Unstructured-IO/unstructured/main/README.md"
     elements = partition(url=url, content_type="text/markdown", strategy=PartitionStrategy.HI_RES)
-    assert "unstructured" in elements[0].text
+    assert "unstructured" in elements[1].text
 
 
 # ================================================================================================
@@ -561,6 +561,7 @@ def test_auto_partition_pdf_with_fast_strategy(request: FixtureRequest):
         strategy=PartitionStrategy.FAST,
         languages=None,
         metadata_filename=None,
+        detect_language_per_element=False,
         infer_table_structure=False,
         extract_images_in_pdf=False,
         extract_image_block_types=None,
@@ -627,6 +628,26 @@ def test_auto_partition_pdf_element_extraction(extract_image_block_to_payload: b
         )
 
 
+def test_auto_partition_html_element_extraction():
+    extract_image_block_types = ["Image"]
+
+    with tempfile.TemporaryDirectory() as tmpdir:
+        elements = partition(
+            example_doc_path("fake-html-with-base64-image.html"),
+            extract_image_block_types=extract_image_block_types,
+            extract_image_block_to_payload=True,
+        )
+
+        assert_element_extraction(elements, extract_image_block_types, True, tmpdir)
+
+
+def test_auto_partition_html_image_with_url():
+    elements = partition(
+        example_doc_path("fake-html-with-image-from-url.html"),
+    )
+    assert elements[1].metadata.image_url is not None
+
+
 def test_partition_pdf_does_not_raise_warning():
     # NOTE(robinson): This is the recommended way to check that no warning is emitted,
     # per the pytest docs.
@@ -1032,7 +1053,23 @@ def test_auto_partition_respects_detect_language_per_element_arg():
 
 
 @pytest.mark.parametrize(
-    "file_extension", "doc docx eml epub html md odt org ppt pptx rst rtf txt xml".split()
+    "file_extension",
+    [
+        "doc",
+        "docx",
+        "eml",
+        "epub",
+        "html",
+        "md",
+        "odt",
+        "org",
+        "ppt",
+        "pptx",
+        "rst",
+        "rtf",
+        "txt",
+        "xml",
+    ],
 )
 def test_auto_partition_respects_language_arg(file_extension: str):
     elements = partition(
@@ -1265,6 +1302,27 @@ def test_auto_partition_passes_user_provided_languages_arg_to_PDF():
     assert all(e.metadata.languages == ["eng"] for e in elements)
 
 
+@pytest.mark.parametrize(
+    "strategy",
+    [
+        PartitionStrategy.FAST,
+        PartitionStrategy.HI_RES,
+        PartitionStrategy.OCR_ONLY,
+    ],
+)
+def test_auto_partition_detects_pdf_language_per_element(strategy):
+    filename = example_doc_path("language-docs/fr_olap.pdf")
+    elements = partition(
+        filename=filename,
+        strategy=strategy,
+        detect_language_per_element=True,
+    )
+
+    assert len(elements) > 0
+    assert elements[0].metadata.languages == ["fra"]
+    assert elements[-1].metadata.languages == ["eng"]
+
+
 def test_auto_partition_languages_argument_default_to_None_when_omitted():
     elements = partition(example_doc_path("handbook-1p.docx"), detect_language_per_element=True)
     # -- PageBreak and any other element with no text is assigned `None` --
@@ -1273,17 +1331,17 @@ def test_auto_partition_languages_argument_default_to_None_when_omitted():
 
 def test_auto_partition_default_does_not_overwrite_other_defaults():
     """`partition()` ["eng"] default does not overwrite ["auto"] default in other partitioners."""
-    # the default for `languages` is ["auto"] in partiton_text
+    # the default for `languages` is ["auto"] in partition_text
     from unstructured.partition.text import partition_text
 
     # Use a document that is primarily in a language other than English
     file_path = example_doc_path("language-docs/UDHR_first_article_all.txt")
     text_elements = partition_text(file_path)
-    assert text_elements[0].metadata.languages != ["eng"]
+    assert text_elements[13].metadata.languages != ["eng"]
 
     auto_elements = partition(file_path)
-    assert auto_elements[0].metadata.languages != ["eng"]
-    assert auto_elements[0].metadata.languages == text_elements[0].metadata.languages
+    assert auto_elements[13].metadata.languages != ["eng"]
+    assert auto_elements[13].metadata.languages == text_elements[13].metadata.languages
 
 
 # ================================================================================================
@@ -1331,3 +1389,17 @@ def expected_docx_elements():
         Text("2023"),
         Address("DOYLESTOWN, PA 18901"),
     ]
+
+
+def _test_partition_foo():
+    pass
+
+
+def test_auto_partition_works_with_custom_types(
+    request: FixtureRequest,
+):
+    file_type = create_file_type("FOO", canonical_mime_type="application/foo", extensions=[".foo"])
+
+    register_partitioner(file_type)(_test_partition_foo)
+    loader = _PartitionerLoader()
+    assert loader.get(file_type) is _test_partition_foo
