@@ -3,7 +3,7 @@ import json
 import os
 import pathlib
 import platform
-from tempfile import NamedTemporaryFile
+import tempfile
 
 import pandas as pd
 import pytest
@@ -15,6 +15,7 @@ from unstructured.documents.elements import (
     CoordinatesMetadata,
     CoordinateSystem,
     DataSourceMetadata,
+    Element,
     ElementMetadata,
     ElementType,
     FigureCaption,
@@ -23,7 +24,7 @@ from unstructured.documents.elements import (
     ListItem,
     NarrativeText,
     PageBreak,
-    RegexMetadata,
+    Table,
     Text,
     Title,
 )
@@ -113,17 +114,12 @@ def test_convert_to_dataframe_maintains_fields():
     elements = partition_email(
         "example-docs/eml/fake-email-attachment.eml",
         process_attachements=True,
-        regex_metadata={"hello": r"Hello", "punc": r"[!]"},
     )
     df = base.convert_to_dataframe(elements)
     for element in elements:
         metadata = element.metadata.to_dict()
         for key in metadata:
-            if not key.startswith("regex_metadata"):
-                assert key in df.columns
-
-    assert "regex_metadata_hello" in df.columns
-    assert "regex_metadata_punc" in df.columns
+            assert key in df.columns
 
 
 def test_default_pandas_dtypes():
@@ -171,7 +167,6 @@ def test_default_pandas_dtypes():
             emphasized_text_contents=["emphasized", "text", "contents"],
             emphasized_text_tags=["emphasized", "text", "tags"],
             text_as_html="text_as_html",
-            regex_metadata={"key": [RegexMetadata(text="text", start=0, end=4)]},
             is_continuation=True,
             detection_class_prob=0.5,
         ),
@@ -249,15 +244,18 @@ def test_serialized_deserialize_elements_to_json(tmpdir: str):
 
 def test_read_and_write_json_with_encoding():
     elements = partition_text("example-docs/fake-text-utf-16-be.txt")
-    with NamedTemporaryFile() as tempfile:
-        base.elements_to_json(elements, filename=tempfile.name, encoding="utf-16")
-        new_elements_filename = base.elements_from_json(filename=tempfile.name, encoding="utf-16")
+
+    with tempfile.TemporaryDirectory() as tmp_dir_path:
+        tmp_file_path = os.path.join(tmp_dir_path, "tmp_file")
+        base.elements_to_json(elements, filename=tmp_file_path, encoding="utf-16")
+        new_elements_filename = base.elements_from_json(filename=tmp_file_path, encoding="utf-16")
+
     assert elements == new_elements_filename
 
 
 def test_filter_element_types_with_include_element_type():
     element_types = [Title]
-    elements = partition_text("example-docs/fake-text.txt", include_metadata=False)
+    elements = partition_text("example-docs/fake-text.txt")
     elements = base.filter_element_types(elements=elements, include_element_types=element_types)
     for element in elements:
         assert type(element) in element_types
@@ -265,7 +263,7 @@ def test_filter_element_types_with_include_element_type():
 
 def test_filter_element_types_with_exclude_element_type():
     element_types = [Title]
-    elements = partition_text("example-docs/fake-text.txt", include_metadata=False)
+    elements = partition_text("example-docs/fake-text.txt")
     elements = base.filter_element_types(elements=elements, exclude_element_types=element_types)
     for element in elements:
         assert type(element) not in element_types
@@ -273,7 +271,7 @@ def test_filter_element_types_with_exclude_element_type():
 
 def test_filter_element_types_with_exclude_and_include_element_type():
     element_types = [Title]
-    elements = partition_text("example-docs/fake-text.txt", include_metadata=False)
+    elements = partition_text("example-docs/fake-text.txt")
     with pytest.raises(ValueError):
         elements = base.filter_element_types(
             elements=elements,
@@ -325,7 +323,6 @@ def test_convert_to_coco():
                 emphasized_text_contents=["emphasized", "text", "contents"],
                 emphasized_text_tags=["emphasized", "text", "tags"],
                 text_as_html="text_as_html",
-                regex_metadata={"key": [RegexMetadata(text="text", start=0, end=4)]},
                 is_continuation=True,
                 detection_class_prob=0.5,
             ),
@@ -369,7 +366,6 @@ def test_convert_to_coco():
                 emphasized_text_contents=["emphasized", "text", "contents"],
                 emphasized_text_tags=["emphasized", "text", "tags"],
                 text_as_html="text_as_html",
-                regex_metadata={"key": [RegexMetadata(text="text", start=0, end=4)]},
                 is_continuation=True,
                 detection_class_prob=0.5,
             ),
@@ -519,3 +515,140 @@ def test_flatten_empty_dict():
 def test_flatten_dict_empty_lists():
     """Flattening a dictionary with empty lists"""
     assert base.flatten_dict({"a": [], "b": {"c": []}}) == {"a": [], "b_c": []}
+
+
+@pytest.mark.parametrize(
+    ("json_filename", "expected_md_filename"),
+    [
+        (
+            "test_unstructured/testfiles/staging/UDHR_first_article_all.txt.json",
+            "test_unstructured/testfiles/staging/UDHR_first_article_all.txt.md",
+        ),
+        (
+            "test_unstructured/testfiles/staging/embedded-images.pdf.json",
+            "test_unstructured/testfiles/staging/embedded-images.pdf.md",
+        ),
+    ],
+)
+def test_elements_to_md_conversion(json_filename: str, expected_md_filename: str):
+    """Test that elements_from_json followed by elements_to_md produces expected markdown output."""
+    # Rehydrate elements from JSON
+    elements = base.elements_from_json(json_filename)
+
+    # Convert to markdown
+    markdown_output = base.elements_to_md(elements)
+
+    # Read expected markdown fixture
+    with open(expected_md_filename) as f:
+        expected_markdown = f.read()
+
+    # Compare outputs
+    assert markdown_output == expected_markdown
+
+
+@pytest.mark.parametrize(
+    ("element", "expected_markdown", "exclude_binary"),
+    [
+        (Title("Test Title"), "# Test Title", False),
+        (NarrativeText("This is some narrative text."), "This is some narrative text.", False),
+        (
+            Image(
+                "Test Image",
+                metadata=ElementMetadata(
+                    image_base64=(
+                        "iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAADUlEQVR42mNkYPhf"
+                        "DwAChwGA60e6kgAAAABJRU5ErkJggg=="
+                    ),
+                    image_mime_type="image/png",
+                ),
+            ),
+            (
+                "![Test Image](data:image/png;base64,"
+                "iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAADUlEQVR42mNkYPhfDwAChwGA60e6kgA"
+                "AAABJRU5ErkJggg==)"
+            ),
+            False,
+        ),
+        (
+            Image(
+                "Test Image",
+                metadata=ElementMetadata(
+                    image_base64=(
+                        "iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAADUlEQVR42mNkYPhfDwAChwGA60"
+                        "e6kgAAAABJRU5ErkJggg=="
+                    ),
+                    image_mime_type="image/png",
+                ),
+            ),
+            "Test Image",
+            True,
+        ),
+        (
+            Image(
+                "Test Image", metadata=ElementMetadata(image_url="https://example.com/image.jpg")
+            ),
+            "![Test Image](https://example.com/image.jpg)",
+            False,
+        ),
+        (
+            Table(
+                "Table Text",
+                metadata=ElementMetadata(text_as_html="<table><tr><td>Test</td></tr></table>"),
+            ),
+            "<table><tr><td>Test</td></tr></table>",
+            False,
+        ),
+        (Table("Table Text"), "Table Text", False),
+    ],
+)
+def test_element_to_md_conversion(element: "Element", expected_markdown: str, exclude_binary: bool):
+    """Test individual element to markdown conversion for different element types."""
+    assert (
+        base.element_to_md(element, exclude_binary_image_data=exclude_binary) == expected_markdown
+    )
+
+
+def test_elements_to_md_file_output():
+    """Test elements_to_md function with file output."""
+
+    elements = [Title("Test Title"), NarrativeText("Test content.")]
+
+    # Test file output
+    with tempfile.NamedTemporaryFile(mode="w", suffix=".md", delete=False) as tmp_file:
+        tmp_filename = tmp_file.name
+
+    try:
+        markdown_content = base.elements_to_md(elements, filename=tmp_filename)
+
+        # Check that the function returns the content
+        assert markdown_content == "# Test Title\nTest content."
+
+        # Check that the file was created with correct content
+        with open(tmp_filename) as f:
+            file_content = f.read()
+        assert file_content == "# Test Title\nTest content."
+
+    finally:
+        # Clean up
+        if os.path.exists(tmp_filename):
+            os.unlink(tmp_filename)
+
+
+def test_element_to_md_with_none_mime_type():
+    """Test element_to_md handles None mime_type gracefully."""
+    from unstructured.documents.elements import ElementMetadata, Image
+
+    # Test Image element with None mime_type
+    image_metadata = ElementMetadata(
+        image_base64=(
+            "iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAADUlEQVR42mNkYPhfDwAChwGA60e6kgAAAABJRU"
+            "5ErkJggg=="
+        ),
+        image_mime_type=None,
+    )
+    image_element = Image("Test Image", metadata=image_metadata)
+
+    # Should handle None mime_type gracefully
+    result = base.element_to_md(image_element)
+    assert "![Test Image](data:image/*" in result
+    assert "base64," in result
