@@ -1,9 +1,11 @@
 from __future__ import annotations
 
 import os
+import re
 import tempfile
 from typing import IO
 
+from unstructured.errors import UnprocessableEntityError
 from unstructured.partition.common.common import exactly_one
 from unstructured.utils import requires_dependencies
 
@@ -14,7 +16,9 @@ def convert_file_to_text(filename: str, source_format: str, target_format: str)
     import pypandoc
 
     try:
-        text = pypandoc.convert_file(filename, target_format, format=source_format)
+        text: str = pypandoc.convert_file(
+            filename, target_format, format=source_format, sandbox=True
+        )
     except FileNotFoundError as err:
         msg = (
             f"Error converting the file to text. Ensure you have the pandoc package installed on"
@@ -23,6 +27,14 @@ def convert_file_to_text(filename: str, source_format: str, target_format: str)
         )
         raise FileNotFoundError(msg)
     except RuntimeError as err:
+        err_str = str(err)
+        if source_format == "epub" and (
+            "Couldn't extract ePub file" in err_str
+            or "No entry on path" in err_str
+            or re.search(r"exitcode ['\"]?64['\"]?", err_str)
+        ):
+            raise UnprocessableEntityError(f"Invalid EPUB file: {err_str}")
+
         supported_source_formats, _ = pypandoc.get_pandoc_formats()
 
         if source_format == "rtf" and source_format not in supported_source_formats:
