@@ -403,7 +403,7 @@ def detect_languages(
     # If text contains special characters (like ñ, å, or Korean/Mandarin/etc.) it will NOT default
     # to English. It will default to English if text is only ascii characters and is short.
     if re.match(r"^[\x00-\x7F]+$", text) and len(text.split()) < 5:
-        logger.warning(f'short text: "{text}". Defaulting to English.')
+        logger.debug(f'short text: "{text}". Defaulting to English.')
         return ["eng"]
 
     # set seed for deterministic langdetect outputs
